function aufruf_gsv(problem)

% Legt die Variablen und Parameter fuer das entsprechende Problem 
% fest und ruft kontrollierte Gauss-Seidel-Verfahren mit linearer 
% Interpolation fuer das entsprechende Problem auf.

% Die Variable problem ist entweder eines der Probleme
% 'wm'    =   Wachstumsmodell                     (Beispiel 1)
% 'oek'   =   Oekologieproblem                    (Beispiel 2)
% 'im'    =   Investitionsmodell                  (Beispiel 3)
% 'kred'  =   Wachstumsmodell mit Kreditaufnahme  (Beispiel 4)
%
% oder ein neues Problem 'neu', das durch die Funktionen fh_neu 
% und g_neu definiert ist.


tic;                            % Start der Messung der Rechenzeit

switch problem
case 'wm'
    fh          =   @fh_wm;             
    g           =   @g_wm;              
    
    startknoten =   17;                 
   
    x_1         =   0.1;                
    
    x_n         =   10;                 
    
    x           =   x_1:((x_n-x_1)/(startknoten-1)):x_n;    

    kontrollen  =   500;                
 
    u_1         =   0.1;                
   
    u_m         =   11;                 
 
    u           =   u_1:((u_m-u_1)/(kontrollen-1)):u_m;     
    
    h           =   1;                  

    delta       =   0.05;               
    
    zeta        =   1e-5;               

    theta       =   0.1;                
                                        
    grenze_kn   =   298;                
   
                      
case 'oek'      % Variablen analog zu oben
    fh          =   @fh_oek;            
    g           =   @g_oek;             
    
    startknoten =   50;                 
    x_1         =   0;                  
    x_n         =   3;                  
    x           =   x_1:((x_n-x_1)/(startknoten-1)):x_n;     

    kontrollen  =   50;                 
    u_1         =   0;                  
    u_m         =   0.4;                
    u           =   u_1:((u_m-u_1)/(kontrollen-1)):u_m;     

    h           =   0.05;               
    delta       =   0.1;                
    
    zeta        =   1e-5;               
                                       
    theta       =   0.1;                
                                        
    grenze_kn   =   225;                
    

    
case 'im'           % Variablen analog zu oben
    fh          =   @fh_im;             
    g           =   @g_im;              
    
    startknoten =   131;                
    x_1         =   0;                  
    x_n         =   0.7;                
    x           =   x_1:((x_n-x_1)/(startknoten-1)):x_n;    

    kontrollen  =   50;                 
    u_1         =   0;                  
    u_m         =   1;                  
    u           =   u_1:((u_m-u_1)/(kontrollen-1)):u_m;     

    h           =   0.05;              
    delta       =   0.2;                
    
    zeta        =   1e-5;               
    
    theta       =   0.3;                
                                        
    grenze_kn   =   307;                
     
    
case 'kred'
    fh          =   @fh_kred;           
    g           =   @g_kred;            
    
    startknoten =   39;                 
    x_1         =   0.0001;             
    x_n         =   2.0001;             
    x           =   x_1:((x_n-x_1)/(startknoten-1)):x_n;    

    kontrollen  =   50;                
    u_1         =   0;                  
    u_m         =   0.25;               
    u           =   u_1:((u_m-u_1)/(kontrollen-1)):u_m;     

    h           =   0.05;               
    delta       =   0.1;               
    
    zeta        =   1e-5;               
    
    theta       =   0.5;                
                                        
    grenze_kn   =   116;                
                                         
    
case 'neu'  % Hier koennen die Daten fuer ein weiteres Problem 
            % abgespeichert werden.
    fh          =   @fh_neu;             
    g           =   @g_neu;             
    
    startknoten =   1;                  
    x_1         =   0;                 
    x_n         =   1;                  
    x           =   x_1:((x_n-x_1)/(startknoten-1)):x_n;    

    kontrollen  =   1;                  
    u_1         =   0;                  
    u_m         =   1;                 
    u           =   u_1:((u_m-u_1)/(kontrollen-1)):u_m;     

    h           =   0.1;                
    delta       =   0.1;                
    
    zeta        =   1e-5;               
    
    theta       =   0.1;                
                                        
    grenze_kn   =   11;                 

    
otherwise     
    fprintf('Unbekanntes Problem!');
    break;
end

% AUFRUF DES ITERATIONSVERFAHRENS MIT DEN FESTGELEGTEN
% PARAMETERN UND FUNKTIONEN

beta    =   1-delta*h;                  % Diskontfaktor wird berechnet

gsv(fh,g,x,u,h,delta,beta,zeta,theta,grenze_kn,problem);

toc                                     % Ausgabe der gesamten Rechenzeit