function aufruf_strategie(problem)

% Legt die Variablen und Parameter fuer das entsprechende Problem 
% fest und ruft das Iterationsverfahren mit Strategie-Iteration
% fuer das entsprechende Problem auf. Von den in dieser Arbeit
% besprochenen Problemen laesst sich nur das Beispiel 1 mit dem
% Verfahren mit Strategie-Iteration loesen.
% Diese Verbesserung des urspruenglichen Verfahrens funktioniert
% nicht bei den Problemen mit nicht global differenzierbarer
% Optimalwertefunktion.

% Die Variable 'problem' ist somit entweder das Problem
%
% 'wm'    =   Wachstumsmodell                     (Beispiel 1)
%
% oder ein neues Problem 'neu', das durch die Funktionen fh_neu 
% und g_neu definiert ist.



tic;                            % Start der Messung der Rechenzeit

switch problem
case 'wm'
    fh          =   @fh_wm;             
    g           =   @g_wm;              
    
    startknoten =   17;                 

    x_1         =   0.1;                

    x_n         =   10;                 

    x           =   x_1:((x_n-x_1)/(startknoten-1)):x_n;    

    kontrollen  =   500;                

    u_1         =   0.1;                
 
    u_m         =   11;                 

    u           =   u_1:((u_m-u_1)/(kontrollen-1)):u_m;     

    h           =   1;                  

    delta       =   0.05;               

    zeta        =   1e-5;               
    
    theta       =   0.1;                
                                        
    grenze_kn   =   250;                
   
    mindest_gleich = 0.8;                          
    % Mindestanteil der bereinstimmung der optimalen Konmtrollwerte
    % Ist dieser Wert ueberschritten, wird zur Strategie-Iteration
    % uebergegangen.
    
    x_vgl       =   x_1:((x_n-x_1)/(1000-1)):x_n;                  
    v_vgl       =   exakt_wm(x_vgl);        

                                            
case 'oek'      
    fprintf('Dieses Problem laesst sich nicht mit Hilfe der Strategie-Iteration loesen!');
    break;
case 'im'          
    fprintf('Dieses Problem laesst sich nicht mit Hilfe der Strategie-Iteration loesen!');
    break;
case 'kred'
    fprintf('Dieses Problem laesst sich nicht mit Hilfe der Strategie-Iteration loesen!');
    break;
case 'neu'  
    fh          =   @fh_neu;             
    g           =   @g_neu;             
    
    startknoten =   1;                  
    x_1         =   0;                 
    x_n         =   1;                  
    x           =   x_1:((x_n-x_1)/(startknoten-1)):x_n;    

    kontrollen  =   1;                  
    u_1         =   0;                  
    u_m         =   1;                 
    u           =   u_1:((u_m-u_1)/(kontrollen-1)):u_m;     

    h           =   0.1;                
    delta       =   0.1;                
    
    zeta        =   1e-5;               
    
    theta       =   0.1;                
                                        
    grenze_kn   =   11;                 
                                        
    [x_vgl, v_vgl]=loesung_linear('neu'); 
    
otherwise     
    fprintf('Unbekanntes Problem!');
    break;
end

% AUFRUF DES ITERATIONSVERFAHRENS MIT DEN FESTGELEGTEN
% PARAMETERN UND FUNKTIONEN

beta    =   1-delta*h;              

verf_mit_splinestrategie(fh,g,x,u,h,delta,beta,zeta,theta,grenze_kn,mindest_gleich,x_vgl,v_vgl,problem);

toc                                